## Base class for training pytorch models

### Usage:

### Launch tensorboard: 

### Visualize prediction dynamics: 
""visualize prediction dynamics. I like to visualize model predictions on a fixed test batch during the course of training. The “dynamics” of how these predictions move will give you incredibly good intuition for how the training progresses. Many times it is possible to feel the network “struggle” to fit your data if it wiggles too much in some way, revealing instabilities. Very low or very high learning rates are also easily noticeable in the amount of jitter."" - http://karpathy.github.io/2019/04/25/recipe/

### Continue training a model after stopping at an epoch

## Metrics

## sanity checks: 
1. check loss reduces on a fixed data samples (say 1 or 2 inputs) by iterating
